@@ -287,8 +287,7 @@ on_selection_changed (GtkTreeSelection     *selection,
 		path = gtk_tree_path_copy ((GtkTreePath *)rows->data);
 	}
 
-	g_list_foreach (rows, (GFunc)gtk_tree_path_free, NULL);
-	g_list_free (rows);
+	g_list_free_full (rows, (GDestroyNotify)gtk_tree_path_free);
 
 	if (!path)
 	{
